@@ -31,9 +31,12 @@ class TokenIterator:
         return self.__next__()
 
     def _filter_matches(self):
-        if self.filter is None:
+        if not self.filter:
             return True
 
+        if self.i + len(self.filter) > len(self.tokens):
+            return False
+
         for i in range(len(self.filter)):
             if self.filter[i] != self.tokens[self.i + i][0]:
                 return False
