@@ -14,6 +14,12 @@ class EBCompilerTestCase(unittest.TestCase):
 
         self.assertEqual(output, '(a IS FALSE AND b IS NULL AND c IS NULL AND d IS NULL AND e IS NULL AND f IS NULL AND g IS NULL) OR (a IS TRUE AND b IS NOT NULL AND c IS NOT NULL AND e IS NOT NULL AND f IS NOT NULL AND g IS NOT NULL)')
 
+    def test_trailing_unary(self):
+        input = 'a && b && c?'
+        output = EBCompiler.convert(input)
+
+        self.assertEqual(output, 'a IS TRUE AND b IS TRUE AND c IS NOT NULL')
+
     def test_syntax_error(self):
         input = '!a < b'
         with self.assertRaises(EBSyntaxError):
